[nautilus-actions/file-manager-actions] nact_schemes_list_xxx are renamed to fma_schemes_list_xxx



commit a702f675b2ba9f6a76288b2dbfb81309216b9202
Author: Pierre Wieser <pwieser trychlos org>
Date:   Tue Sep 8 20:28:41 2015 +0200

    nact_schemes_list_xxx are renamed to fma_schemes_list_xxx

 src/ui/Makefile.am                                 |    4 +-
 src/ui/fma-add-scheme-dialog.c                     |   14 +++---
 src/ui/fma-preferences-editor.c                    |   12 ++--
 src/ui/{nact-schemes-list.c => fma-schemes-list.c} |   50 ++++++++++----------
 src/ui/{nact-schemes-list.h => fma-schemes-list.h} |   24 +++++-----
 5 files changed, 52 insertions(+), 52 deletions(-)
---
diff --git a/src/ui/Makefile.am b/src/ui/Makefile.am
index 2fc3cd6..794d549 100644
--- a/src/ui/Makefile.am
+++ b/src/ui/Makefile.am
@@ -126,8 +126,8 @@ fma_config_tool_SOURCES = \
        fma-preferences-editor.h                                                        \
        fma-providers-list.c                                                            \
        fma-providers-list.h                                                            \
-       nact-schemes-list.c                                                                     \
-       nact-schemes-list.h                                                                     \
+       fma-schemes-list.c                                                                      \
+       fma-schemes-list.h                                                                      \
        nact-sort-buttons.c                                                                     \
        nact-sort-buttons.h                                                                     \
        nact-statusbar.c                                                                        \
diff --git a/src/ui/fma-preferences-editor.c b/src/ui/fma-preferences-editor.c
index 771c504..18c5fa2 100644
--- a/src/ui/fma-preferences-editor.c
+++ b/src/ui/fma-preferences-editor.c
@@ -49,7 +49,7 @@
 #include "fma-application.h"
 #include "base-gtk-utils.h"
 #include "fma-main-window.h"
-#include "nact-schemes-list.h"
+#include "fma-schemes-list.h"
 #include "fma-providers-list.h"
 #include "fma-preferences-editor.h"
 
@@ -398,7 +398,7 @@ instance_dispose( GObject *dialog )
 
                self->private->dispose_has_run = TRUE;
 
-               nact_schemes_list_dispose( BASE_WINDOW( self ));
+               fma_schemes_list_dispose( BASE_WINDOW( self ));
                fma_providers_list_dispose( BASE_WINDOW( self ));
 
                /* chain up to the parent class */
@@ -495,7 +495,7 @@ on_base_initialize_gtk( FMAPreferencesEditor *editor, GtkDialog *toplevel, gpoin
                fma_ioptions_list_gtk_init( FMA_IOPTIONS_LIST( editor ), container, TRUE );
 
                listview = GTK_TREE_VIEW( base_window_get_widget( BASE_WINDOW( editor ), "SchemesTreeView" ));
-               nact_schemes_list_create_model( listview, SCHEMES_LIST_FOR_PREFERENCES );
+               fma_schemes_list_create_model( listview, SCHEMES_LIST_FOR_PREFERENCES );
 
                listview = GTK_TREE_VIEW( base_window_get_widget( BASE_WINDOW( editor ), "ProvidersTreeView" 
));
                fma_providers_list_create_model( listview );
@@ -569,7 +569,7 @@ on_base_initialize_window( FMAPreferencesEditor *editor, gpointer user_data )
                /* sixth tab: default schemes
                 */
                listview = GTK_TREE_VIEW( base_window_get_widget( BASE_WINDOW( editor ), "SchemesTreeView" ));
-               nact_schemes_list_init_view( listview, BASE_WINDOW( editor ), NULL, NULL );
+               fma_schemes_list_init_view( listview, BASE_WINDOW( editor ), NULL, NULL );
 
                /* seventh tab: I/O providers priorities
                 */
@@ -603,7 +603,7 @@ on_base_show_widgets( FMAPreferencesEditor *editor, gpointer user_data )
                notebook = GTK_NOTEBOOK( base_window_get_widget( BASE_WINDOW( editor ), "PreferencesNotebook" 
));
                gtk_notebook_set_current_page( notebook, st_last_tab );
 
-               nact_schemes_list_show_all( BASE_WINDOW( editor ));
+               fma_schemes_list_show_all( BASE_WINDOW( editor ));
        }
 }
 
@@ -1265,7 +1265,7 @@ on_dialog_ok( BaseDialog *dialog )
 
                /* sixth tab: list of default schemes
                 */
-               nact_schemes_list_save_defaults( BASE_WINDOW( editor ));
+               fma_schemes_list_save_defaults( BASE_WINDOW( editor ));
 
                /* seventh tab: priorities of I/O providers
                 */
diff --git a/src/ui/nact-schemes-list.h b/src/ui/fma-schemes-list.h
similarity index 79%
rename from src/ui/nact-schemes-list.h
rename to src/ui/fma-schemes-list.h
index 035f69c..4e871fa 100644
--- a/src/ui/nact-schemes-list.h
+++ b/src/ui/fma-schemes-list.h
@@ -27,13 +27,13 @@
  *   ... and many others (see AUTHORS)
  */
 
-#ifndef __UI_NACT_SCHEMES_LIST_H__
-#define __UI_NACT_SCHEMES_LIST_H__
+#ifndef __UI_FMA_SCHEMES_LIST_H__
+#define __UI_FMA_SCHEMES_LIST_H__
 
 /**
- * SECTION: nact_schemes_list
+ * SECTION: fma_schemes_list
  * @short_description: Schemes list view management.
- * @include: ui/nact-schemes-list.h
+ * @include: ui/fma-schemes-list.h
  *
  * This set of functions manages the schemes list view.
  *
@@ -79,14 +79,14 @@ enum {
        SCHEMES_LIST_FOR_ADD_FROM_DEFAULTS
 };
 
-void    nact_schemes_list_create_model      ( GtkTreeView *treeview, guint mode );
-void    nact_schemes_list_init_view         ( GtkTreeView *treeview, BaseWindow *window, pf_new_selection_cb 
pf, void *user_data );
-void    nact_schemes_list_setup_values      ( BaseWindow *window, GSList *schemes );
-void    nact_schemes_list_show_all          ( BaseWindow *window );
-gchar  *nact_schemes_list_get_current_scheme( BaseWindow *window );
-void    nact_schemes_list_save_defaults     ( BaseWindow *window );
-void    nact_schemes_list_dispose           ( BaseWindow *window );
+void    fma_schemes_list_create_model      ( GtkTreeView *treeview, guint mode );
+void    fma_schemes_list_init_view         ( GtkTreeView *treeview, BaseWindow *window, pf_new_selection_cb 
pf, void *user_data );
+void    fma_schemes_list_setup_values      ( BaseWindow *window, GSList *schemes );
+void    fma_schemes_list_show_all          ( BaseWindow *window );
+gchar  *fma_schemes_list_get_current_scheme( BaseWindow *window );
+void    fma_schemes_list_save_defaults     ( BaseWindow *window );
+void    fma_schemes_list_dispose           ( BaseWindow *window );
 
 G_END_DECLS
 
-#endif /* __UI_NACT_SCHEMES_LIST_H__ */
+#endif /* __UI_FMA_SCHEMES_LIST_H__ */


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/ui/fma-add-scheme-dialog.c b/src/ui/fma-add-scheme-dialog.c
index a2da1a9..2429862 100644
--- a/src/ui/fma-add-scheme-dialog.c
+++ b/src/ui/fma-add-scheme-dialog.c
@@ -37,7 +37,7 @@
 
 #include "core/fma-settings.h"
 
-#include "nact-schemes-list.h"
+#include "fma-schemes-list.h"
 #include "fma-add-scheme-dialog.h"
 #include "fma-main-window.h"
 
@@ -297,7 +297,7 @@ on_base_initialize_gtk( FMAAddSchemeDialog *dialog, GtkDialog *toplevel, gpointe
                                thisfn, ( void * ) dialog, ( void * ) toplevel, ( void * ) user_data );
 
                listview = GTK_TREE_VIEW( base_window_get_widget( BASE_WINDOW( dialog ), "SchemesTreeView" ));
-               nact_schemes_list_create_model( listview, SCHEMES_LIST_FOR_ADD_FROM_DEFAULTS );
+               fma_schemes_list_create_model( listview, SCHEMES_LIST_FOR_ADD_FROM_DEFAULTS );
        }
 }
 
@@ -314,9 +314,9 @@ on_base_initialize_window( FMAAddSchemeDialog *dialog, gpointer user_data )
                g_debug( "%s: dialog=%p, user_data=%p", thisfn, ( void * ) dialog, ( void * ) user_data );
 
                listview = GTK_TREE_VIEW( base_window_get_widget( BASE_WINDOW( dialog ), "SchemesTreeView" ));
-               nact_schemes_list_init_view( listview, BASE_WINDOW( dialog ), ( pf_new_selection_cb ) 
on_selection_changed, ( void * ) dialog );
+               fma_schemes_list_init_view( listview, BASE_WINDOW( dialog ), ( pf_new_selection_cb ) 
on_selection_changed, ( void * ) dialog );
 
-               nact_schemes_list_setup_values( BASE_WINDOW( dialog ), dialog->private->already_used );
+               fma_schemes_list_setup_values( BASE_WINDOW( dialog ), dialog->private->already_used );
 
                /* catch double-click */
                base_window_signal_connect(
@@ -352,7 +352,7 @@ on_base_show_widgets( FMAAddSchemeDialog *dialog, gpointer user_data )
 
                g_debug( "%s: dialog=%p, user_data=%p", thisfn, ( void * ) dialog, ( void * ) user_data );
 
-               nact_schemes_list_show_all( BASE_WINDOW( dialog ));
+               fma_schemes_list_show_all( BASE_WINDOW( dialog ));
        }
 }
 
@@ -385,7 +385,7 @@ on_ok_clicked( GtkButton *button, FMAAddSchemeDialog *dialog )
 }
 
 /*
  * this function is a callback, called from nact-schemes-list:on_selection_changed
  * this let us validate/invalidate the OK button
  */
 static void
@@ -424,5 +424,5 @@ static void
 on_dialog_ok( BaseDialog *dialog )
 {
        FMAAddSchemeDialog *editor = FMA_ADD_SCHEME_DIALOG( dialog );
-       editor->private->scheme = nact_schemes_list_get_current_scheme( BASE_WINDOW( dialog ));
+       editor->private->scheme = fma_schemes_list_get_current_scheme( BASE_WINDOW( dialog ));
 }
@@ -385,7 +385,7 @@ on_ok_clicked( GtkButton *button, FMAAddSchemeDialog *dialog )
 
 /*
- * this function is a callback, called from nact-schemes-list:on_selection_changed
+ * this function is a callback, called from fma-schemes-list:on_selection_changed
  * this let us validate/invalidate the OK button
  */
diff --git a/src/ui/nact-schemes-list.c b/src/ui/fma-schemes-list.c
similarity index 94%
rename from src/ui/nact-schemes-list.c
rename to src/ui/fma-schemes-list.c
index 57ba3d4..a784bc4 100644
--- a/src/ui/nact-schemes-list.c
+++ b/src/ui/fma-schemes-list.c
@@ -40,7 +40,7 @@
 #include "fma-application.h"
 #include "base-gtk-utils.h"
 #include "fma-main-tab.h"
-#include "nact-schemes-list.h"
+#include "fma-schemes-list.h"
 
 /* data attached to the treeview widget on initial load
  * at this time, only treeview and mode are set
@@ -73,8 +73,8 @@ enum {
        SCHEMES_N_COLUMN
 };
 
-#define SCHEMES_LIST_DATA                              "nact-schemes-list-data"
-#define SCHEMES_LIST_TREEVIEW                  "nact-schemes-list-treeview"
+#define SCHEMES_LIST_DATA                              "fma-schemes-list-data"
+#define SCHEMES_LIST_TREEVIEW                  "fma-schemes-list-treeview"
 
 static void             init_view_setup_defaults( SchemesListData *data );
 static GSList          *init_view_get_default_list( SchemesListData *data );
@@ -107,7 +107,7 @@ static GtkButton       *get_remove_button( BaseWindow *window );
 static SchemesListData *get_schemes_list_data( GtkTreeView *treeview );
 
 /**
- * nact_schemes_list_create_schemes_list:
+ * fma_schemes_list_create_schemes_list:
  * @treeview: the #GtkTreeView.
  * @mode: whether we are opening this listview for preferences edition,
  *  or to add a new scheme from the default list.
@@ -130,9 +130,9 @@ static SchemesListData *get_schemes_list_data( GtkTreeView *treeview );
  *   list is not a mandatory pref.
  */
 void
-nact_schemes_list_create_model( GtkTreeView *treeview, guint mode )
+fma_schemes_list_create_model( GtkTreeView *treeview, guint mode )
 {
-       static const char *thisfn = "nact_schemes_list_create_model";
+       static const char *thisfn = "fma_schemes_list_create_model";
        GtkListStore *model;
        GtkTreeViewColumn *column;
        GtkCellRenderer *text_cell;
@@ -179,7 +179,7 @@ nact_schemes_list_create_model( GtkTreeView *treeview, guint mode )
 }
 
 /**
- * nact_schemes_list_init_view:
+ * fma_schemes_list_init_view:
  * @treeview: the #GtkTreeView.
  * @window: the parent #BaseWindow which embeds the view.
  * @pf: a callback function which will be called on selection change.
@@ -192,13 +192,13 @@ nact_schemes_list_create_model( GtkTreeView *treeview, guint mode )
  * initialization.
  *
  * When mode is for add from defaults, i.e. when editing #FMAIContext schemes
  * conditions, then #nact_schemes_list_setup_values() must also be called in
  * order to actually setup the already used schemes.
  */
 void
-nact_schemes_list_init_view( GtkTreeView *treeview, BaseWindow *window, pf_new_selection_cb pf, void 
*user_data )
+fma_schemes_list_init_view( GtkTreeView *treeview, BaseWindow *window, pf_new_selection_cb pf, void 
*user_data )
 {
-       static const gchar *thisfn = "nact_schemes_list_init_view";
+       static const gchar *thisfn = "fma_schemes_list_init_view";
        SchemesListData *data;
        FMAApplication *application;
        FMAUpdater *updater;
@@ -370,14 +370,14 @@ init_view_select_first_row( SchemesListData *data )
 }
 
 /**
- * nact_schemes_list_setup_values:
+ * fma_schemes_list_setup_values:
  * @window: the #BaseWindow which embeds this treeview.
  * @schemes: a #GSList of already used schemes.
  *
  * Set the used schemes for the current #FMAIContext.
  */
 void
-nact_schemes_list_setup_values( BaseWindow *window, GSList *schemes )
+fma_schemes_list_setup_values( BaseWindow *window, GSList *schemes )
 {
        GtkTreeView *treeview;
        GtkTreeModel *model;
@@ -409,13 +409,13 @@ setup_values_iter( GtkTreeModel *model, GtkTreePath *path, GtkTreeIter* iter, GS
 }
 
 /**
- * nact_schemes_list_show_all:
+ * fma_schemes_list_show_all:
  * @window: the #BaseWindow which embeds this treeview.
  *
  * Update visibility of widgets after all widgets are showed.
  */
 void
-nact_schemes_list_show_all( BaseWindow *window )
+fma_schemes_list_show_all( BaseWindow *window )
 {
        GtkTreeView *listview;
        SchemesListData *data;
@@ -436,14 +436,14 @@ nact_schemes_list_show_all( BaseWindow *window )
 }
 
 /**
- * nact_schemes_list_get_current_scheme:
+ * fma_schemes_list_get_current_scheme:
  * @window: the #BaseWindow which embeds this treeview.
  *
  * Returns: the currently selected scheme, if any, as a newly allocated
  * string which should be g_free() by the caller.
  */
 gchar *
-nact_schemes_list_get_current_scheme( BaseWindow *window )
+fma_schemes_list_get_current_scheme( BaseWindow *window )
 {
        GtkTreeView *treeview;
        GtkTreeSelection *selection;
@@ -468,7 +468,7 @@ nact_schemes_list_get_current_scheme( BaseWindow *window )
 }
 
 /**
- * nact_schemes_list_save_defaults:
+ * fma_schemes_list_save_defaults:
  * @window: the #BaseWindow which embeds this treeview.
  *
  * Save the list of schemes as a GConf preference.
@@ -477,7 +477,7 @@ nact_schemes_list_get_current_scheme( BaseWindow *window )
  * where each string is of the form 'keyword|description'.
  */
 void
-nact_schemes_list_save_defaults( BaseWindow *window )
+fma_schemes_list_save_defaults( BaseWindow *window )
 {
        GtkTreeView *treeview;
        GSList *schemes;
@@ -520,13 +520,13 @@ get_list_schemes_iter( GtkTreeModel *model, GtkTreePath *path, GtkTreeIter* iter
 }
 
 /**
- * nact_schemes_list_dispose:
+ * fma_schemes_list_dispose:
  * @treeview: the #GtkTreeView.
  */
 void
-nact_schemes_list_dispose( BaseWindow *window )
+fma_schemes_list_dispose( BaseWindow *window )
 {
-       static const gchar *thisfn = "nact_schemes_list_dispose";
+       static const gchar *thisfn = "fma_schemes_list_dispose";
        GtkTreeView *treeview;
        GtkTreeModel *model;
        GtkTreeSelection *selection;
@@ -546,7 +546,7 @@ on_key_pressed_event( GtkWidget *widget, GdkEventKey *event, BaseWindow *window
 {
        gboolean stop;
 
-       /*g_debug( "nact_schemes_list_on_key_pressed_event" );*/
+       /*g_debug( "fma_schemes_list_on_key_pressed_event" );*/
 
        stop = FALSE;
 
@@ -571,7 +571,7 @@ on_key_pressed_event( GtkWidget *widget, GdkEventKey *event, BaseWindow *window
 static void
 on_selection_changed( GtkTreeSelection *selection, BaseWindow *window )
 {
-       /*static const gchar *thisfn = "nact_schemes_list_on_selection_changed";*/
+       /*static const gchar *thisfn = "fma_schemes_list_on_selection_changed";*/
        GtkButton *button;
        GtkTreeView *listview;
        SchemesListData *data;
@@ -623,7 +623,7 @@ on_remove_clicked( GtkButton *button, BaseWindow *window )
 static void
 on_desc_edited( GtkCellRendererText *renderer, const gchar *path, const gchar *text, BaseWindow *window )
 {
-       static const gchar *thisfn = "nact_schemes_list_on_desc_edited";
+       static const gchar *thisfn = "fma_schemes_list_on_desc_edited";
 
        g_debug( "%s: renderer=%p, path=%s, text=%s, window=%p",
                        thisfn, ( void * ) renderer, path, text, ( void * ) window );
@@ -661,7 +661,7 @@ edit_cell( BaseWindow *window, const gchar *path_string, const gchar *text, gint
 static void
 edit_inline( BaseWindow *window )
 {
-       static const gchar *thisfn = "nact_schemes_list_edit_inline";
+       static const gchar *thisfn = "fma_schemes_list_edit_inline";
        GtkTreeView *listview;
        GtkTreeSelection *selection;
        GList *listrows;
@@ -192,13 +192,13 @@ nact_schemes_list_create_model( GtkTreeView *treeview, guint mode )
  *
  * When mode is for add from defaults, i.e. when editing #FMAIContext schemes
- * conditions, then #nact_schemes_list_setup_values() must also be called in
+ * conditions, then #fma_schemes_list_setup_values() must also be called in
  * order to actually setup the already used schemes.
  */